@@ -16,8 +16,10 @@
 
 from __future__ import annotations
 
+import contextlib
 import os
 import sys
+import tracemalloc
 import warnings
 
 from setproctitle import getproctitle
@@ -29,9 +31,9 @@ if sys.flags.dev_mode and not (
     or "PYTHONWARNINGS" in os.environ
     or " -W" in " ".join(sys.orig_argv)
 ):
+    warnings.simplefilter("error", EncodingWarning)
     warnings.simplefilter("error", DeprecationWarning)
 warnings.filterwarnings("ignore", module="defusedxml")
-warnings.filterwarnings("default", module="aioredis.connection")
 
 
 from . import patches
@@ -42,4 +44,10 @@ patches.apply()
 from .main import main
 
 if __name__ == "__main__":
+    if sys.flags.dev_mode:
+        tracemalloc.start()
+        if sys.version_info >= (3, 12):
+            with contextlib.suppress(ValueError):
+                sys.activate_stack_trampoline("perf")
+
     sys.exit(main())
