@@ -22,6 +22,7 @@ from functools import cache
 import regex
 from tornado.web import HTTPError
 
+from ..utils.data_parsing import parse_args
 from ..utils.request_handler import APIRequestHandler, HTMLRequestHandler
 from ..utils.utils import ModuleInfo, length_of_match, n_from_set
 from . import FILE_NAMES, LANGUAGES, get_letters, get_words
@@ -126,7 +127,7 @@ def filter_words(
     matches_always: bool = False,
 ) -> tuple[frozenset[str], dict[str, int]]:
     """Filter a set of words to get only those that match the regex."""
-    # if "words" is string it is a file_name
+    # if "words" is string it is a filename
     if isinstance(words, str):
         words = get_words(words)
 
@@ -169,7 +170,7 @@ def filter_words(
 
 
 def get_words_and_letters(
-    file_name: str,
+    filename: str,
     input_str: str,
     invalid: str,
     crossword_mode: bool,
@@ -179,12 +180,12 @@ def get_words_and_letters(
     matches_always = not invalid and not input_letters
 
     if matches_always and not crossword_mode:
-        return get_words(file_name), get_letters(file_name)
+        return get_words(filename), get_letters(filename)
 
     pattern = generate_pattern_str(input_str, invalid, crossword_mode)
 
     return filter_words(
-        file_name,
+        filename,
         regex.compile(pattern, regex.ASCII),  # pylint: disable=no-member
         input_letters,
         crossword_mode,
@@ -192,7 +193,29 @@ def get_words_and_letters(
     )
 
 
-def solve_hangman(
+@dataclass
+class HangmanArguments:
+    """Arguments for the hangman solver."""
+
+    max_words: int = 20
+    crossword_mode: bool = False
+    lang: str = "de_only_a-z"
+    input: str = ""
+    invalid: str = ""
+
+
+def solve_hangman(data: HangmanArguments) -> Hangman:
+    """Generate a hangman object based on the input and return it."""
+    return _solve_hangman(
+        max_words=max(20, min(100, data.max_words)),
+        crossword_mode=data.crossword_mode,
+        language=data.lang,
+        input_str=data.input,
+        invalid=data.invalid,
+    )
+
+
+def _solve_hangman(
     input_str: str,
     invalid: str,
     language: str,
@@ -209,9 +232,9 @@ def solve_hangman(
     input_len = len(input_str)
 
     # to be short (is only the key of the words dict in __init__.py)
-    file_name = f"words_{language}/{input_len}"
+    filename = f"words_{language}/{input_len}"
 
-    if file_name not in FILE_NAMES:
+    if filename not in FILE_NAMES:
         # no words with the length
         return Hangman(
             input=input_str,
@@ -223,7 +246,7 @@ def solve_hangman(
 
     # do the solving
     matched_words, letters = get_words_and_letters(
-        file_name, input_str, invalid, crossword_mode
+        filename, input_str, invalid, crossword_mode
     )
 
     return Hangman(
@@ -243,30 +266,14 @@ class HangmanSolver(HTMLRequestHandler):
 
     RATELIMIT_GET_LIMIT = 10
 
-    async def get(self, *, head: bool = False) -> None:
+    @parse_args(type_=HangmanArguments, name="data")
+    async def get(self, *, data: HangmanArguments, head: bool = False) -> None:
         """Handle GET requests to the hangman solver page."""
         if head:
             return
-        hangman = self.get_hangman_obj()
+        hangman = solve_hangman(data)
         await self.render("pages/hangman_solver.html", **asdict(hangman))
 
-    def get_hangman_obj(self) -> Hangman:
-        """Get the information and return the Hangman object."""
-        max_words = self.get_int_argument("max_words", 20, min_=0, max_=100)
-
-        crossword_mode = self.get_bool_argument("crossword_mode", False)
-        language = str(self.get_argument("lang", "de_only_a-z"))
-        input_str = str(self.get_argument("input", ""))
-        invalid = str(self.get_argument("invalid", ""))
-
-        return solve_hangman(
-            max_words=max_words,
-            crossword_mode=crossword_mode,
-            language=language,
-            input_str=input_str,
-            invalid=invalid,
-        )
-
 
 class HangmanSolverAPI(APIRequestHandler, HangmanSolver):
     """Request handler for the hangman solver API."""
@@ -274,11 +281,12 @@ class HangmanSolverAPI(APIRequestHandler, HangmanSolver):
     RATELIMIT_GET_LIMIT = 10
     IS_NOT_HTML = True
 
-    async def get(self, *, head: bool = False) -> None:
+    @parse_args(type_=HangmanArguments, name="data")
+    async def get(self, *, data: HangmanArguments, head: bool = False) -> None:
         """Handle GET requests to the hangman solver API."""
         if head:
             return
-        hangman = self.get_hangman_obj()
+        hangman = solve_hangman(data)
         hangman_dict = asdict(hangman)
         # convert set to list, because the set can't be converted to JSON
         hangman_dict["words"] = list(hangman_dict["words"])
