@@ -376,6 +376,12 @@ def apply_config_to_app(app: Application, config: BetterConfigParser) -> None:
         "GENERAL", "NETCUP", fallback=False
     )
 
+    app.settings["COMMITTERS_URI"] = config.get(
+        "GENERAL",
+        "COMMITTERS_URI",
+        fallback="https://github.asozial.org/an-website/committers.txt",
+    )
+
     onion_address = config.get("GENERAL", "ONION_ADDRESS", fallback=None)
     app.settings["ONION_ADDRESS"] = onion_address
     if onion_address is None:
@@ -842,7 +848,7 @@ async def heartbeat() -> None:
     global HEARTBEAT  # pylint: disable=global-statement
     while True:  # pylint: disable=while-used
         HEARTBEAT = time.monotonic()
-        await asyncio.sleep(0)
+        await asyncio.sleep(0.05)
 
 
 def supervise(loop: AbstractEventLoop) -> None:
