@@ -15,7 +15,6 @@
 
 from __future__ import annotations
 
-import logging
 from typing import cast
 
 from editdistance import distance
@@ -34,8 +33,6 @@ from .utils import (
     parse_quote,
 )
 
-logger = logging.getLogger(__name__)
-
 
 async def create_quote(quote_str: str, author: Author) -> Quote:
     """Create a quote."""
