@@ -75,16 +75,17 @@ SMART_RATING_FILTERS: Final[tuple[RatingFilter, ...]] = (
 
 def parse_rating_filter(rating_filter_str: str) -> RatingFilter:
     """Get a rating filter."""
-    if rating_filter_str == "w":
-        return "w"
-    if rating_filter_str == "n":
-        return "n"
-    if rating_filter_str == "unrated":
-        return "unrated"
-    if rating_filter_str == "rated":
-        return "rated"
-    if rating_filter_str == "all":
-        return "all"
+    match rating_filter_str:
+        case "w":
+            return "w"
+        case "n":
+            return "n"
+        case "unrated":
+            return "unrated"
+        case "rated":
+            return "rated"
+        case "all":
+            return "all"
     return "smart"
 
 
@@ -110,7 +111,7 @@ def get_next_id(rating_filter: RatingFilter) -> tuple[int, int]:
         case "n":
             wrong_quotes = get_wrong_quotes(lambda wq: wq.rating < 0)
         case "rated":
-            wrong_quotes = get_wrong_quotes()
+            wrong_quotes = get_wrong_quotes(lambda wq: wq.id not in {-1, None})
         case _:
             wrong_quotes = ()
 
@@ -139,8 +140,9 @@ class QuoteBaseHandler(QuoteReadyCheckHandler):
         self.FUTURES.discard(future)
         if exc := future.exception():
             LOGGER.error(
-                "Failed to pre-fetch quote %d-%d",
+                "Failed to pre-fetch quote %d-%d (%s)",
                 *self.next_id,
+                exc,
                 exc_info=(type(exc), exc, exc.__traceback__),
             )
         else:
