@@ -15,13 +15,16 @@
 
 from __future__ import annotations
 
+import argparse
 import asyncio
 import contextlib
 import os
+import pathlib
 import random
 import time
 from base64 import b85encode
-from collections.abc import Callable, Sequence
+from collections.abc import Callable, Iterable, Sequence
+from configparser import ConfigParser
 from dataclasses import dataclass, field
 from datetime import datetime
 from enum import IntFlag
@@ -111,6 +114,8 @@ class Permission(IntFlag):
     BACKDOOR = 4
     UPDATE = 8
     REPORTING = 16
+    SHORTEN = 32
+    UPLOAD = 64
 
 
 # sortable, so the pages can be linked in an order
@@ -761,6 +766,117 @@ def str_to_bool(val: None | str | bool, default: None | bool = None) -> bool:
     return default
 
 
+def str_to_set(string: str) -> set[str]:
+    """Convert a string to a set of strings."""
+    return {part.strip() for part in string.split(",") if part.strip()}
+
+
+class ArgparseNamespace(argparse.Namespace):
+    """A class to fake type hints for argparse Namespace."""
+
+    # pylint: disable=too-few-public-methods
+    __slots__ = ("config", "port", "save_config_to")
+
+    config: list[pathlib.Path]
+    port: list[int]
+    save_config_to: pathlib.Path | None
+
+
+def parse_command_line_arguments() -> ArgparseNamespace:
+    """Parse command line arguments."""
+    parser = argparse.ArgumentParser()
+    parser.add_argument(
+        "-c",
+        "--config",
+        default=[pathlib.Path("config.ini")],
+        help="the path to the config file",
+        metavar="PATH",
+        nargs="*",
+        type=pathlib.Path,
+    )
+    parser.add_argument(
+        "--port",
+        "-p",
+        default=[],
+        help="the port to use",
+        metavar="PORT",
+        nargs="*",
+        type=int,
+    )
+    parser.add_argument(
+        "--save-config-to",
+        default=None,
+        help="save the configuration to a file",
+        metavar="Path",
+        nargs="?",
+        type=pathlib.Path,
+    )
+    return parser.parse_args(namespace=ArgparseNamespace())
+
+
+class BetterConfigParser(ConfigParser):
+    """A better config parser."""
+
+    getset: Callable[..., set[str]]
+
+    def __init__(self, *args, **kwargs) -> None:  # type: ignore[no-untyped-def]
+        """Initialize this config parser."""
+        converters = kwargs.setdefault("converters", {})
+        converters["set"] = str_to_set
+        kwargs.setdefault("interpolation", None)
+        kwargs["dict_type"] = dict
+        super().__init__(*args, **kwargs)
+
+    def _add_fallback_to_config(
+        self,
+        section: str,
+        option: str,
+        fallback: str | Iterable[str] | bool | int | float | None,
+    ) -> None:
+        if section in self and option in self[section]:
+            return
+        if isinstance(fallback, str):
+            pass
+        elif isinstance(fallback, Iterable):
+            fallback = ", ".join([str(val) for val in fallback])
+        elif isinstance(fallback, bool):
+            fallback = bool_to_str(fallback)
+        elif fallback is None:
+            fallback = ""
+            option = f"#{option}"
+        else:
+            fallback = str(fallback)  # float, int
+        if section not in self.sections():
+            self.add_section(section)
+        self.set(section, option.lower(), fallback)
+
+    def _get_conv(
+        self, section: str, option: str, conv: Callable[[str], T], **kwargs: Any
+    ) -> T:
+        value: T = super()._get_conv(section, option, conv, **kwargs)
+        if "fallback" in kwargs:
+            self._add_fallback_to_config(
+                section, option, kwargs.get("fallback")
+            )
+        return value
+
+    def get(self, section: str, option: str, **kwargs: Any) -> None | str:  # type: ignore[override]  # noqa: B950  # pylint: disable=line-too-long, useless-suppression
+        """Get an option in a section."""
+        value: None | str = super().get(section, option, **kwargs)
+        if "fallback" in kwargs:
+            self._add_fallback_to_config(
+                section, option, kwargs.get("fallback")
+            )
+        return value
+
+
+def parse_config(*path: pathlib.Path) -> BetterConfigParser:
+    """Parse the config at the given path."""
+    config = BetterConfigParser()
+    config.read(path, encoding="UTF-8")
+    return config
+
+
 def time_function(function: Callable[..., T], *args: Any) -> tuple[T, float]:
     """Run the function and return the result and the time it took in s."""
     timer = Timer()
