@@ -10,4 +10,4 @@ fi
 
 echo "Writing config to ${TARGET}"
 
-sed -e "s|<home>|${HOME}|g" -e "s/<lang>/${LANG}/g" -e "s/<user>/${USER}/g" "an_website.ini" > "${TARGET}"
+sed -e "s|<home>|${HOME}|g" -e "s|<lang>|${LANG}|g" -e "s|<user>|${USER}|g" "an_website.ini" > "${TARGET}"
